@@ -133,15 +133,17 @@ pub fn interval_float<T: fmt::Write>(fm: &mut T, a: f64, step: Option<f64>) -> f
 
 pub fn find_bounds<K: PartialOrd + Copy>(
     it: impl IntoIterator<Item = [K; 2]>,
-    xmarkers: impl IntoIterator<Item=K>,
-    ymarkers: impl IntoIterator<Item=K>) -> Option<[K; 4]> {
+    xmarkers: impl IntoIterator<Item = K>,
+    ymarkers: impl IntoIterator<Item = K>,
+) -> Option<[K; 4]> {
     let mut ii = it.into_iter();
-    
+
     if let Some([x, y]) = ii.next() {
         let mut val = [x, x, y, y];
 
-        let ii=ii.chain(xmarkers.into_iter().map(|xx|[xx,y]))
-        .chain(ymarkers.into_iter().map(|yy|[x,yy]));
+        let ii = ii
+            .chain(xmarkers.into_iter().map(|xx| [xx, y]))
+            .chain(ymarkers.into_iter().map(|yy| [x, yy]));
 
         ii.fold(&mut val, |val, [x, y]| {
             if x < val[0] {
@@ -161,5 +163,4 @@ pub fn find_bounds<K: PartialOrd + Copy>(
         //If there isnt any plots to draw, then no point looking at the markers.
         None
     }
-
 }
